#!/bin/bash
## basic functions for the debian eclipse startscript

## Sets the JAVA_BIN variable, if java could be found. 
## Returns with 1, if no java could be found.
function findJava(){
if [ "$JAVACMD" != "" ] ; then
   echo "Using $JAVACMD as java virtual machine..."
   return 0
fi
if [ "$JAVA_HOME" != "" ] ; then
   echo "Using JAVA_HOME and $JAVA_HOME/bin/java as java virtual machine..."
   JAVACMD="$JAVA_HOME/bin/java"
else
   if [ -x /usr/bin/java ] ; then
      echo "Using default /usr/bin/java as java virtual machine..."
      JAVACMD="/usr/bin/java"
   else
      echo "ERROR: No java virtual machine found!"
      return 1
   fi
fi
}

## Starts eclipse in a loop, so that it is restarted, when eclipse 
## exits with a special error code.

function startEclipse()
{
# startupProblemExitCode = 13;
# vmVersionExitCode      = 14;
# isRunningExitCode      = 15;
# restartExitCode        = 23;

local ret
ret="23"
setEclipseStartLine
local restarted="no"
while [ "$ret" = "23" ] ; do
  if [ "$SPLASH" = "off" ] ; then
     if [ ! "${DEBUG_PARAM}" = "" ] ; then
       echo "$ECLIPSE $OPTIONS" ;
     fi
     $ECLIPSE $OPTIONS
  else
     if [ ! "${DEBUG_PARAM}" = "" ] ; then
       echo "$ECLIPSE -showsplash "$SPLASH_PARAM" $OPTIONS"
     fi
     $ECLIPSE -showsplash "$SPLASH_PARAM" $OPTIONS
  fi  
  ret="$?"
  
  #workaround for first startup, when two WS are installed...
  if [ ${ret} -ne 0 ] && [ "${restarted}" = "no" ] && grep -q "list" "$WORKSPACE/.metadata/.config/platform.cfg" ; then
     execWorkarounds;
     ret=23;
     restarted="yes";
  fi
done

if [ ${ret} -ne 0 ] ; then
  # Something went wrong...
  if [ "$ret" = "14" ] ; then
     echo "ERROR: Please use a newer VM. Eclipse requires at least 1.3.0."
     echo "-> edit $HOME/.eclipse/eclipsrc -> JAVA_HOME=<path to your JVM>";
  elif [ "$ret" = "15" ] ; then
     echo "ERROR: Another session is already running in the associated workspace."
     echo "If this is not the case, please delete the \".lock\" file in the"
     echo "workspace \".metadata\" directory and try starting the platform again"
  elif [ "$JAVACMD" = "/usr/bin/java" ] ; then
     echo "ERROR: eclipse crashed, The reason *could* be, that /usr/bin/java"
     echo "was used as java virtual machine and that this VM isn't fit to run"
     echo "eclipse. If thats the case, please edit $HOME/.eclipse/eclipsrc, so"
     echo "that JAVA_HOME points to the right VM."
     echo ""
     echo "If that is not the reason, please check $WORKSPACE/.metadata/.log for"
     echo "errors. Also, read /usr/share/doc/eclipse-platform/README.Debian"
     echo "for possible reasons, why eclipse crashed."
  else
     echo "CRASH: Check $WORKSPACE/.metadata/.log for errors. Also, read"
     echo "/usr/share/doc/eclipse-platform/README.Debian for possible"
     echo "reasons, why eclipse crashed."
  fi
fi
}

## Computes the command which is then started.
function setEclipseStartLine()
{ 
  local LAUNCH_MAIN
  local JAVA_PART
  LAUNCH_MAIN="-classpath $ECLIPSE_DIR/startup.jar org.eclipse.core.launcher.Main"
  
  findJava
  
  JAVA_PART="$JAVACMD $VMARGS_PARAM $LAUNCH_MAIN"
  OPTIONS="-data $WORKSPACE $DEBUG_PARAM $ADDSITE_PARAM $ARGS"
  ECLIPSE="$JAVA_PART $WS_PARAM -os linux -arch x86"
  
}

## Sets the Configured values
function setConfigValues()
{

# constants
ECLIPSE_DIR=/usr/share/eclipse

# Default values
WS_PARAM="-ws gtk"
WORKSPACE=$HOME/eclipse
ARGS=""
SPLASH_PARAM="$ECLIPSE_DIR/eclipse -showsplash 600"

# The system WS value
if [ -r /usr/share/java-config/libswt2.1-java ] ; then
  . /usr/share/java-config/libswt2.1-java
fi

# User defaults
if [ -r $HOME/.eclipse/eclipserc ] ; then
   echo "Including user settings ~/.eclipse/eclipserc..."
   # include the rc in users home directory.
   . $HOME/.eclipse/eclipserc
else
   setupUserConfig
fi
userParamChecks
}

function userParamChecks()
{
      
if [ "$DEBUG_OPTIONS" != "" ] ;  then
   DEBUG_PARAM="-consolelog -debug $DEBUG_OPTIONS"
fi

if [ "$WS" != "" ] ; then 
   WS_PARAM="$WS"
fi
if [ "$VMARGS" != "" ] ; then 
   VMARGS_PARAM="$VMARGS"
fi
if [ "$LINKS" != "" ] ; then
   ADDSITE_PARAM="-addsite $LINKS"
fi
}		  
   
function setupUserConfig()
{
echo "Setting up user Settings..."
echo "Edit $HOME/.eclipse/eclipserc to change the default settings."

if [ -e $HOME/.eclipse ] && [ ! -d $HOME/.eclipse ] ; then
   echo
   echo "ERROR: \$HOME/.eclipse is not a directory."
   echo
   echo "Please remove \$HOME/.eclipse, so that eclipse can use this as a"
   echo "directory to place some configuration files in there."
   echo
   exit 1
fi
local DIR=$(pwd)
if [ ! -e $HOME/.eclipse ] ; then
   mkdir $HOME/.eclipse
fi
if [ ! -w  $HOME/.eclipse ] ; then
   echo
   echo "ERROR: Cannot write to \$HOME/.eclipse!"
   echo
   echo "Please change the file permissions of \$HOME/.eclipse to be"
   echo "writeable by you."
   echo
   exit 1
fi
cp $ECLIPSE_DIR/eclipserc $HOME/.eclipse/eclipserc
cp $ECLIPSE_DIR/debug_options $HOME/.eclipse/debug_options
   
if [ ! -e $HOME/.eclipse/user.links ] ; then
   echo "path=$HOME/.eclipse" > $HOME/.eclipse/user.links
   if [ ! -e $HOME/.eclipse/eclipse ] ; then 
     cd $HOME/.eclipse/
     mkdir eclipse
     cd eclipse
     mkdir plugins
     mkdir features
     cd $DIR
   fi
fi
}
	
function usage()
{
echo "Eclipse Starter Script"
echo "Usage:"
echo "eclipse [options [value]]"
echo "See eclipse(1) for more information."
echo ""
echo "Also see ~/.eclipse/eclipserc, which provides some default values"
}

function checkWorkspace()
{
if [ -d $WORKSPACE ] ; then
  echo "Using $WORKSPACE as default workspace..."
else
  echo "Creating $WORKSPACE directory to be used as default workspace..."
  if [ -f $WORKSPACE ] ; then
     echo "ERROR: $WORKSPACE is a file and can not be used as workspace directory";
     exit 1;
  fi
  mkdir $WORKSPACE
fi
}									


function execWorkarounds()
{
# This is a workaround for excluded plugins at startup time which will
# result in a ClassNotFoundError or 'Default Application not Found' error.
# See README.Debian for more info...
platform="$WORKSPACE/.metadata/.config/platform.cfg"
if [ -w $platform ] ; then
    if  grep -q "list" $platform  ; then    
      bak="$WORKSPACE/.metadata/.config/platform.cfg.bak"
      mv $platform $bak
      echo "Backed up bogus platform.cfg..."
#      sed 's/.*\.list.*//g' < $bak > $platform
      sed 's|^site\.[0-9]*\.list\.[0-9]*=.*\n||g;' < $bak > $platform
    fi
fi
}
						    
